@@ -5,7 +5,7 @@
     <name>mxtools</name>
     <message>
         <location filename="../mxtools.ui" line="14"/>
-        <location filename="../mxtools.cpp" line="334"/>
+        <location filename="../mxtools.cpp" line="364"/>
         <source>MX Tools</source>
         <translation>MX Narzędzia</translation>
     </message>
@@ -27,7 +27,7 @@
     <message>
         <location filename="../mxtools.ui" line="116"/>
         <source>Close application</source>
-        <translation type="unfinished"></translation>
+        <translation>Zamknij program</translation>
     </message>
     <message>
         <location filename="../mxtools.ui" line="119"/>
@@ -42,7 +42,7 @@
     <message>
         <location filename="../mxtools.ui" line="149"/>
         <source>Manual</source>
-        <translation>Instrukcja</translation>
+        <translation>Podręcznik</translation>
     </message>
     <message>
         <location filename="../mxtools.ui" line="248"/>
@@ -57,47 +57,47 @@
     <message>
         <location filename="../mxtools.ui" line="283"/>
         <source>search</source>
-        <translation type="unfinished"></translation>
+        <translation>szukaj</translation>
     </message>
     <message>
-        <location filename="../mxtools.cpp" line="333"/>
+        <location filename="../mxtools.cpp" line="363"/>
         <source>About MX Tools</source>
         <translation>O MX Narzędzia</translation>
     </message>
     <message>
-        <location filename="../mxtools.cpp" line="334"/>
+        <location filename="../mxtools.cpp" line="364"/>
         <source>Version: </source>
         <translation>Wersja:</translation>
     </message>
     <message>
-        <location filename="../mxtools.cpp" line="336"/>
+        <location filename="../mxtools.cpp" line="366"/>
         <source>Configuration Tools for MX Linux</source>
-        <translation>Narzędzia konfiguracyjne dla dystrybucji antiX MX</translation>
+        <translation>Narzędzia konfiguracyjne dla MX Linux</translation>
     </message>
     <message>
-        <location filename="../mxtools.cpp" line="337"/>
+        <location filename="../mxtools.cpp" line="367"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mxtools.cpp" line="338"/>
+        <location filename="../mxtools.cpp" line="368"/>
         <source>License</source>
         <translation>Licencja</translation>
     </message>
     <message>
-        <location filename="../mxtools.cpp" line="339"/>
+        <location filename="../mxtools.cpp" line="369"/>
         <source>Changelog</source>
-        <translation type="unfinished"></translation>
+        <translation>Dziennik zmian</translation>
     </message>
     <message>
-        <location filename="../mxtools.cpp" line="340"/>
+        <location filename="../mxtools.cpp" line="370"/>
         <source>Cancel</source>
         <translation>Anuluj</translation>
     </message>
     <message>
-        <location filename="../mxtools.cpp" line="355"/>
+        <location filename="../mxtools.cpp" line="385"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Zamknij</translation>
     </message>
 </context>
 </TS>
