@@ -5,9 +5,9 @@
     <name>mxtools</name>
     <message>
         <location filename="../mxtools.ui" line="14"/>
-        <location filename="../mxtools.cpp" line="334"/>
+        <location filename="../mxtools.cpp" line="364"/>
         <source>MX Tools</source>
-        <translation>MX Ferramentas </translation>
+        <translation>MX Ferramentas</translation>
     </message>
     <message>
         <location filename="../mxtools.ui" line="47"/>
@@ -47,7 +47,7 @@
     <message>
         <location filename="../mxtools.ui" line="248"/>
         <source>These MX applications save time and effort with important tasks.</source>
-        <translation>Estas ferramentas do MX poupam tempo e esforço ao executarem tarefas importantes.</translation>
+        <translation>Estas aplicações do MX poupam tempo e esforço na execução de tarefas importantes.</translation>
     </message>
     <message>
         <location filename="../mxtools.ui" line="264"/>
@@ -60,42 +60,42 @@
         <translation>procurar</translation>
     </message>
     <message>
-        <location filename="../mxtools.cpp" line="333"/>
+        <location filename="../mxtools.cpp" line="363"/>
         <source>About MX Tools</source>
-        <translation>Sobre o MX-Ferramentas </translation>
+        <translation>Sobre o MX Ferramentas </translation>
     </message>
     <message>
-        <location filename="../mxtools.cpp" line="334"/>
+        <location filename="../mxtools.cpp" line="364"/>
         <source>Version: </source>
-        <translation>Versão:</translation>
+        <translation>Versão: </translation>
     </message>
     <message>
-        <location filename="../mxtools.cpp" line="336"/>
+        <location filename="../mxtools.cpp" line="366"/>
         <source>Configuration Tools for MX Linux</source>
-        <translation>Ferramentas de configuração do MX Linux</translation>
+        <translation>Ferramentas de configuração do MX</translation>
     </message>
     <message>
-        <location filename="../mxtools.cpp" line="337"/>
+        <location filename="../mxtools.cpp" line="367"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mxtools.cpp" line="338"/>
+        <location filename="../mxtools.cpp" line="368"/>
         <source>License</source>
         <translation>Licença</translation>
     </message>
     <message>
-        <location filename="../mxtools.cpp" line="339"/>
+        <location filename="../mxtools.cpp" line="369"/>
         <source>Changelog</source>
         <translation>Relatório de alterações</translation>
     </message>
     <message>
-        <location filename="../mxtools.cpp" line="340"/>
+        <location filename="../mxtools.cpp" line="370"/>
         <source>Cancel</source>
         <translation>Cancelar</translation>
     </message>
     <message>
-        <location filename="../mxtools.cpp" line="355"/>
+        <location filename="../mxtools.cpp" line="385"/>
         <source>&amp;Close</source>
         <translation>&amp;Fechar</translation>
     </message>
